@@ -72,8 +72,9 @@ def html_profile(environ, start_response):
 
     store = environ['tiddlyweb.store']
 
+    # Confirm username is a real User
     try:
-        _ = store.get(User(username))
+        store.get(User(username))
     except NoUserError:
         raise HTTP404('Profile not found for %s' % username)
 
@@ -204,7 +205,7 @@ try:
                     'hub.mode': 'publish',
                     'hub.url': profile_atom_url(
                         {'tiddlyweb.config': self.config}, user),
-                    }
+            }
 
             try:
                 target = self.config['atom.hub']
